Community
=========

The Xsuite community is open to feedback and contributions.


Issue tracking
--------------

In case of any questions, suggestions or issues feel free to open an
`issue on the Xsuite GitHub page <https://github.com/xsuite/xsuite/issues>`_.

Mattermost channel
------------------

We also host the Xsuite community on `CERN Mattermost <https://mattermost.web.cern.ch/xsuite>`_,
where you can ask questions and discuss with the developers and other users.
The Mattermost community is accessible to anyone with a CERN account, and a guest
account can easily be created for those unaffiliated with CERN, by simply
following the above link, clicking 'Login with CERN SSO', then choosing
'External email – Guest access' or 'Sign in with a social account'.